import { Component, OnInit } from '@angular/core';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { Tab1Service } from '../tab1/tab1.service';
import { Evento } from '../evento';
import { Router } from '@angular/router';
import { Eventoi } from '../interfaces/eventoi';
import { DatePipe } from '@angular/common'
import { ViewEventoPageRoutingModule } from '../view-evento/view-evento-routing.module';

@Component({
  selector: 'app-prompt-evento',
  templateUrl: './prompt-evento.page.html',
  styleUrls: ['./prompt-evento.page.scss'],
})
export class PromptEventoPage implements OnInit{
  submitted = false;
  eventoForm = new FormGroup({
      nombre: new FormControl(null, Validators.required),
      fecha: new FormControl(null, Validators.required),
      hora: new FormControl(null, Validators.required),
      precio1: new FormControl(null, Validators.required),
      precio2: new FormControl(null, Validators.required),
      descripcion: new FormControl(null, Validators.required),
  });

  eventos: Eventoi[];

  constructor(private tab1Service: Tab1Service, private router: Router) {

   }
  
   ngOnInit(){
    if (this.tab1Service.editarEvento==true){
      this.eventoForm = this.tab1Service.eventoForms[this.tab1Service.eventoIndex];
    }
  }
  onSubmit(){
    this.submitted = true;
    if (this.eventoForm.valid){
      let evento = new Evento();
      this.asignarEvento(evento);

    }
  }
  asignarEvento(evento: Evento){
    evento.setNombre(this.eventoForm.get('nombre').value);
    evento.setDesc(this.eventoForm.get('descripcion').value);
    var fecha = this.eventoForm.get('fecha').value;
    fecha = fecha.split("T")[0];
    evento.setFecha(fecha);
    var hora = this.eventoForm.get('hora').value;
    hora = hora.split("T")[1];
    hora = hora.split(":")[0]+(":")+hora.split(":")[1];
    evento.setHora(hora);
    evento.setPrecio1(this.eventoForm.get('precio1').value);
    evento.setPrecio2(this.eventoForm.get('precio2').value);
    //evento.setDia(evento.getFecha()); el datetime de Ion devuelve un String, no se puede 
    if (!this.tab1Service.eventos){
      this.tab1Service.initEventos();}
    if(!this.tab1Service.eventoForms){
      this.tab1Service.initEventoForms();}
    let eventoInterface = this.interfaceEvento(evento);
    if(this.tab1Service.editarEvento==true){
      this.tab1Service.updateEvento(eventoInterface);
      //this.tab1Service.eventos[this.tab1Service.eventoIndex] = evento;
      //this.tab1Service.eventoForms[this.tab1Service.eventoIndex] = this.eventoForm;
    }
    else{
      this.tab1Service.eventos.push(evento);
      this.tab1Service.postEvento(eventoInterface);
      //this.tab1Service.eventos.push(evento);
      //this.tab1Service.eventoForms.push(this.eventoForm);
    }
    
  }

  get nombre(){
    return this.eventoForm.get('nombre');
  }

  get fecha(){
    return this.eventoForm.get('fecha');
  }

  get hora(){
    return this.eventoForm.get('hora');
  }

  get precio1() {
    return this.eventoForm.get('precio1');
  }

  get precio2() {
    return this.eventoForm.get('precio2');
  }

  get descripcion(){
    return this.eventoForm.get('descripcion');
  }

  interfaceEvento(evento: Evento): Eventoi{
    let eventoInterface: Eventoi;
    eventoInterface = {
      discotecaID: this.tab1Service.discotecaI.discotecaID,
      nombre: evento.nombre,
      localizacion: this.tab1Service.discotecaI.localizacion,
      fecha: evento.fecha,
      hora: evento.hora,
      descripcion: evento.descripcion,
      precio1: evento.precio1,
      precio2: evento.precio2,
    }

    return eventoInterface;
  }

  

}
